import { Body, Controller, Get, Post } from '@nestjs/common'
import { AuthService } from './auth.service'
import { CreateUserDto } from 'src/users/dto/create-user.dto'
import { ApiTags } from '@nestjs/swagger'
import { LoginInputDto } from './dto/login-input.dto'
import { Token } from 'src/common/decorators/token.decorator'
import { NeedAuth } from 'src/common/decorators/need-auth.decorator'
import { UsersService } from 'src/users/users.service'

@ApiTags('auth')
@Controller()
export class AuthController {
  constructor(
    private readonly authService: AuthService,
    private readonly userService: UsersService,
  ) {}

  @Post('api/register')
  async register(@Body() userData: CreateUserDto) {
    return this.authService.register(userData)
  }

  @Post('api/login')
  async login(@Body() user: LoginInputDto) {
    return this.authService.login(user.email, user.password)
  }

  @NeedAuth()
  @Get('api/profile')
  async getUserInfo(@Token('userId') userId: string) {
    const user = await this.userService.findUser({ id: userId })
    return user
  }
}
